@@ -30,6 +30,7 @@ __all__ = (
     "ResourceStatusValueType",
     "SearchResourcesPaginatorName",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -323,3 +324,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_group_resources", "list_groups", "search_resources"]
